@@ -15,23 +15,23 @@ class TeaModel:
     @staticmethod
     def validate_required(prop, prop_name):
         if prop is None:
-            raise RequiredArgumentException(prop_name + ' is required.')
+            raise RequiredArgumentException(prop_name)
 
     @staticmethod
     def validate_max_length(prop, prop_name, max_length):
         if len(prop) > max_length:
-            raise Exception(prop_name + ' is exceed max-length : ' + max_length)
+            raise Exception('%s is exceed max-length: %s' % (prop_name, max_length))
 
     @staticmethod
     def validate_min_length(prop, prop_name, min_length):
         if len(prop) < min_length:
-            raise Exception(prop_name + ' is less than min-length : ' + min_length)
+            raise Exception('%s is less than min-length: %s' % (prop_name, min_length))
 
     @staticmethod
     def validate_pattern(prop, prop_name, pattern):
         match_obj = re.search(pattern, str(prop), re.M | re.I)
         if not match_obj:
-            raise Exception(prop_name + ' is not match : ' + pattern)
+            raise Exception('%s is not match: %s' % (prop_name, pattern))
 
     @staticmethod
     def validate_maximum(num, maximum):
